==> qtjambi-designer-5.15.7-sources.jar: io/qt/designer/QDesignerMemberSheetExtension.java <==
package io.qt.designer;


/**
 * <p>Allows you to manipulate a widget's member functions which is displayed when configuring connections using Qt Designer's mode for editing signals and slots</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html">QDesignerMemberSheetExtension</a></p>
 */
public interface QDesignerMemberSheetExtension extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerMemberSheetExtension}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerMemberSheetExtension
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerMemberSheetExtension.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public int count(){
                return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static int count_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String declaredInClass(int index){
                return declaredInClass_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String declaredInClass_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public int indexOf(java.lang.String name){
                return indexOf_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static int indexOf_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean inheritedFromWidget(int index){
                return inheritedFromWidget_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean inheritedFromWidget_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isSignal(int index){
                return isSignal_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean isSignal_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isSlot(int index){
                return isSlot_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean isSlot_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isVisible(int index){
                return isVisible_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean isVisible_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String memberGroup(int index){
                return memberGroup_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String memberGroup_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String memberName(int index){
                return memberName_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String memberName_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.core.QByteArray> parameterNames(int index){
                return parameterNames_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.util.List<io.qt.core.QByteArray> parameterNames_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.core.QByteArray> parameterTypes(int index){
                return parameterTypes_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.util.List<io.qt.core.QByteArray> parameterTypes_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setMemberGroup(int index, java.lang.String group){
                setMemberGroup_native_int_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), index, group);
            }
            private native static void setMemberGroup_native_int_cref_QString(long __this__nativeId, int index, java.lang.String group);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setVisible(int index, boolean b){
                setVisible_native_int_bool(QtJambi_LibraryUtilities.internal.nativeId(this), index, b);
            }
            private native static void setVisible_native_int_bool(long __this__nativeId, int index, boolean b);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String signature(int index){
                return signature_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String signature_native_int_constfct(long __this__nativeId, int index);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerMemberSheetExtension instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#count">QDesignerMemberSheetExtension::count()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract int count();
        
        private native static int count_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#declaredInClass">QDesignerMemberSheetExtension::declaredInClass(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String declaredInClass(int index);
        
        private native static java.lang.String declaredInClass_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#indexOf">QDesignerMemberSheetExtension::indexOf(QString)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract int indexOf(java.lang.String name);
        
        private native static int indexOf_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#inheritedFromWidget">QDesignerMemberSheetExtension::inheritedFromWidget(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean inheritedFromWidget(int index);
        
        private native static boolean inheritedFromWidget_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSignal">QDesignerMemberSheetExtension::isSignal(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean isSignal(int index);
        
        private native static boolean isSignal_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSlot">QDesignerMemberSheetExtension::isSlot(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean isSlot(int index);
        
        private native static boolean isSlot_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isVisible">QDesignerMemberSheetExtension::isVisible(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean isVisible(int index);
        
        private native static boolean isVisible_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberGroup">QDesignerMemberSheetExtension::memberGroup(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String memberGroup(int index);
        
        private native static java.lang.String memberGroup_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberName">QDesignerMemberSheetExtension::memberName(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String memberName(int index);
        
        private native static java.lang.String memberName_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterNames">QDesignerMemberSheetExtension::parameterNames(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.core.QByteArray> parameterNames(int index);
        
        private native static java.util.List<io.qt.core.QByteArray> parameterNames_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterTypes">QDesignerMemberSheetExtension::parameterTypes(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.core.QByteArray> parameterTypes(int index);
        
        private native static java.util.List<io.qt.core.QByteArray> parameterTypes_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setMemberGroup">QDesignerMemberSheetExtension::setMemberGroup(int,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setMemberGroup(int index, java.lang.String group);
        
        private native static void setMemberGroup_native_int_cref_QString(long __this__nativeId, int index, java.lang.String group);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setVisible">QDesignerMemberSheetExtension::setVisible(int,bool)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setVisible(int index, boolean b);
        
        private native static void setVisible_native_int_bool(long __this__nativeId, int index, boolean b);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#signature">QDesignerMemberSheetExtension::signature(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String signature(int index);
        
        private native static java.lang.String signature_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#count">QDesignerMemberSheetExtension::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public int count();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#declaredInClass">QDesignerMemberSheetExtension::declaredInClass(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String declaredInClass(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#indexOf">QDesignerMemberSheetExtension::indexOf(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public int indexOf(java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#inheritedFromWidget">QDesignerMemberSheetExtension::inheritedFromWidget(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean inheritedFromWidget(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSignal">QDesignerMemberSheetExtension::isSignal(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean isSignal(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSlot">QDesignerMemberSheetExtension::isSlot(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean isSlot(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isVisible">QDesignerMemberSheetExtension::isVisible(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean isVisible(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberGroup">QDesignerMemberSheetExtension::memberGroup(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String memberGroup(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberName">QDesignerMemberSheetExtension::memberName(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String memberName(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterNames">QDesignerMemberSheetExtension::parameterNames(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.core.QByteArray> parameterNames(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterTypes">QDesignerMemberSheetExtension::parameterTypes(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.core.QByteArray> parameterTypes(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setMemberGroup">QDesignerMemberSheetExtension::setMemberGroup(int,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void setMemberGroup(int index, java.lang.String group);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setVisible">QDesignerMemberSheetExtension::setVisible(int,bool)</a></p>
     */
    @io.qt.QtUninvokable
    public void setVisible(int index, boolean b);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#signature">QDesignerMemberSheetExtension::signature(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String signature(int index);
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QDesignerMemberSheetExtension.java <==
package io.qt.designer;


/**
 * <p>Allows you to manipulate a widget's member functions which is displayed when configuring connections using Qt Designer's mode for editing signals and slots</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html">QDesignerMemberSheetExtension</a></p>
 */
public interface QDesignerMemberSheetExtension extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerMemberSheetExtension}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerMemberSheetExtension
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerMemberSheetExtension.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public int count(){
                return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static int count_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String declaredInClass(int index){
                return declaredInClass_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String declaredInClass_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public int indexOf(java.lang.String name){
                return indexOf_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static int indexOf_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean inheritedFromWidget(int index){
                return inheritedFromWidget_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean inheritedFromWidget_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isSignal(int index){
                return isSignal_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean isSignal_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isSlot(int index){
                return isSlot_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean isSlot_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean isVisible(int index){
                return isVisible_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static boolean isVisible_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String memberGroup(int index){
                return memberGroup_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String memberGroup_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String memberName(int index){
                return memberName_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String memberName_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.core.QByteArray> parameterNames(int index){
                return parameterNames_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.util.List<io.qt.core.QByteArray> parameterNames_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.core.QByteArray> parameterTypes(int index){
                return parameterTypes_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.util.List<io.qt.core.QByteArray> parameterTypes_native_int_constfct(long __this__nativeId, int index);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setMemberGroup(int index, java.lang.String group){
                setMemberGroup_native_int_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), index, group);
            }
            private native static void setMemberGroup_native_int_cref_QString(long __this__nativeId, int index, java.lang.String group);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setVisible(int index, boolean b){
                setVisible_native_int_bool(QtJambi_LibraryUtilities.internal.nativeId(this), index, b);
            }
            private native static void setVisible_native_int_bool(long __this__nativeId, int index, boolean b);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String signature(int index){
                return signature_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
            }
            private native static java.lang.String signature_native_int_constfct(long __this__nativeId, int index);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerMemberSheetExtension instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#count">QDesignerMemberSheetExtension::count()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract int count();
        
        private native static int count_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#declaredInClass">QDesignerMemberSheetExtension::declaredInClass(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String declaredInClass(int index);
        
        private native static java.lang.String declaredInClass_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#indexOf">QDesignerMemberSheetExtension::indexOf(QString)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract int indexOf(java.lang.String name);
        
        private native static int indexOf_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#inheritedFromWidget">QDesignerMemberSheetExtension::inheritedFromWidget(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean inheritedFromWidget(int index);
        
        private native static boolean inheritedFromWidget_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSignal">QDesignerMemberSheetExtension::isSignal(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean isSignal(int index);
        
        private native static boolean isSignal_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSlot">QDesignerMemberSheetExtension::isSlot(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean isSlot(int index);
        
        private native static boolean isSlot_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isVisible">QDesignerMemberSheetExtension::isVisible(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean isVisible(int index);
        
        private native static boolean isVisible_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberGroup">QDesignerMemberSheetExtension::memberGroup(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String memberGroup(int index);
        
        private native static java.lang.String memberGroup_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberName">QDesignerMemberSheetExtension::memberName(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String memberName(int index);
        
        private native static java.lang.String memberName_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterNames">QDesignerMemberSheetExtension::parameterNames(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.core.QByteArray> parameterNames(int index);
        
        private native static java.util.List<io.qt.core.QByteArray> parameterNames_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterTypes">QDesignerMemberSheetExtension::parameterTypes(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.core.QByteArray> parameterTypes(int index);
        
        private native static java.util.List<io.qt.core.QByteArray> parameterTypes_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setMemberGroup">QDesignerMemberSheetExtension::setMemberGroup(int,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setMemberGroup(int index, java.lang.String group);
        
        private native static void setMemberGroup_native_int_cref_QString(long __this__nativeId, int index, java.lang.String group);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setVisible">QDesignerMemberSheetExtension::setVisible(int,bool)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setVisible(int index, boolean b);
        
        private native static void setVisible_native_int_bool(long __this__nativeId, int index, boolean b);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#signature">QDesignerMemberSheetExtension::signature(int)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String signature(int index);
        
        private native static java.lang.String signature_native_int_constfct(long __this__nativeId, int index);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#count">QDesignerMemberSheetExtension::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public int count();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#declaredInClass">QDesignerMemberSheetExtension::declaredInClass(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String declaredInClass(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#indexOf">QDesignerMemberSheetExtension::indexOf(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public int indexOf(java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#inheritedFromWidget">QDesignerMemberSheetExtension::inheritedFromWidget(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean inheritedFromWidget(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSignal">QDesignerMemberSheetExtension::isSignal(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean isSignal(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isSlot">QDesignerMemberSheetExtension::isSlot(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean isSlot(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#isVisible">QDesignerMemberSheetExtension::isVisible(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean isVisible(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberGroup">QDesignerMemberSheetExtension::memberGroup(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String memberGroup(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#memberName">QDesignerMemberSheetExtension::memberName(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String memberName(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterNames">QDesignerMemberSheetExtension::parameterNames(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.core.QByteArray> parameterNames(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#parameterTypes">QDesignerMemberSheetExtension::parameterTypes(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.core.QByteArray> parameterTypes(int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setMemberGroup">QDesignerMemberSheetExtension::setMemberGroup(int,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void setMemberGroup(int index, java.lang.String group);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#setVisible">QDesignerMemberSheetExtension::setVisible(int,bool)</a></p>
     */
    @io.qt.QtUninvokable
    public void setVisible(int index, boolean b);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesignermembersheetextension.html#signature">QDesignerMemberSheetExtension::signature(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String signature(int index);
    
}
